%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  LaTeX-2e package file "SURVISHNO"                      			%%%%%%%%%%
%%	Description: LaTeX class file for the SURVISHNO conference	
%%	Contact: Hugo ANDRE hugo.andre@univ-st-etienne.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesPackage{SURVISHNO}
\LoadClass[11pt,oneside]{article}
\RequirePackage[francais, english]{babel} % use option [francais] for french accentuated characters
\RequirePackage[latin1]{inputenc} % european characters can be used (Windows, old Linux)
\RequirePackage{times}
\RequirePackage{bbding} %for special item characters
\RequirePackage{graphicx}
\RequirePackage[a4paper, hmargin=2cm, vmargin={1.5cm,2.5cm}, noheadfoot]{geometry}
\RequirePackage{fancyhdr}
\RequirePackage{mathptmx} % changes the default roman fonts to times and these virtual fonts will be used for maths
%%% add here all additional packages you do need %%%

\setlength{\footskip} {15mm}

\pagestyle{fancy}
\fancyhf{} %remove default LaTeX headers and footers
\renewcommand{\headrulewidth}{0pt}
\lhead{}
\rhead{}
\rfoot{\thepage} %\bfseries (bold) or \itshape (italics): puts the page number on the right end of the page

\makeatletter
\renewcommand\maketitle{\par %\begin{titlepage} to add before \par to put only the abstract on the first page
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \@maketitle%
    \thispagestyle{fancy}\@thanks
  \endgroup
%  \end{titlepage} to add here in order to terminate the \begin{titlepage} command
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\renewcommand{\abstract}[1]
  {\date{\flushleft\parbox[t]{\textwidth}{%
         \textbf{\Large Abstract}\\ \normalsize #1}
        }%
  }

%default settings for the article class except the \parident {0mm}
\renewcommand{\paragraph}{%
  \@startsection{paragraph}{4}%
  {\z@}{3.25ex \@plus 1ex \@minus .2ex}{-1em}%
  {\normalfont\normalsize\bfseries}
  {\setlength{\parident}{6mm}}%
}

\let \@afterindentfalse =\@afterindenttrue %add indent after sectional headings, like \chapter and \section

\renewcommand\thesection      {\@arabic\c@section}
\renewcommand\thesubsection   {\thesection.\@arabic\c@subsection}

\renewcommand\section{\@startsection {section}{1}{\z@} %no indent
{-3.5ex \@plus -1ex \@minus -.2ex}%
{2.3ex \@plus.2ex}%
{\normalfont\Large\bfseries}}%\sffamily removed to look like word version

\renewcommand\subsection{\@startsection{subsection}{2}{25\p@} %1pt=0.35mm
{-3.25ex\@plus -1ex \@minus -.2ex}%
{1.5ex \@plus .2ex}%
{\normalfont\large\bfseries}}

\renewcommand\subsubsection{\@startsection{subsubsection}{3}{25\p@} %%1pt=0.35mm
{-3.25ex\@plus -1ex \@minus -.2ex}%
{1.5ex \@plus .2ex}%
{\normalfont\normalsize\bfseries}}
\makeatother